@@ -34,6 +34,8 @@ sub test_git : Tests {
         like( capturex( 'git', 'status' ), qr/Your branch is ahead/, "unpushed" );
     };
 
+    my $lib_dirs = join q{ }, map { realpath($_) } qw( lib t/lib );
+
     # Create the repo
     #
     run( "git", "init", $work_dir );
@@ -55,13 +57,15 @@ sub test_git : Tests {
     # git add foo.txt and make sure it is now in uncommitted list
     #
     run( "git", "add", "foo.txt" );
-    cmp_deeply( [ git_uncommitted_files($work_dir) ],
-        ["$work_dir/foo.txt"], "one uncommitted file" );
+    cmp_deeply(
+        [ git_uncommitted_files($work_dir) ],
+        ["$work_dir/foo.txt"], "one uncommitted file"
+    );
 
     # Add pre-commit hook
     #
     my $precommit_hook_file = "$hooks_dir/pre-commit";
-    my $precommit_hook = sprintf( $precommit_hook_template, realpath("lib") );
+    my $precommit_hook = sprintf( $precommit_hook_template, $lib_dirs );
     write_file( $precommit_hook_file, $precommit_hook );
     chmod( 0775, $precommit_hook_file );
 
@@ -91,7 +95,7 @@ sub test_git : Tests {
     # Add prereceive hook to shared repo
     #
     my $prereceive_hook_file = "$shared_dir/hooks/pre-receive";
-    my $prereceive_hook = sprintf( $prereceive_hook_template, realpath("lib") );
+    my $prereceive_hook = sprintf( $prereceive_hook_template, $lib_dirs );
     write_file( $prereceive_hook_file, $prereceive_hook );
     chmod( 0775, $prereceive_hook_file );
 
